/*
 * Copyright 2010 Mihai Niculescu <q.quark@gmail.com>
 *
 * This file is part of EqualX Project (https://launchpad.net/equalx/)
 *
 * EqualX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EqualX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DEFINES_H
#define DEFINES_H

#define APP_FULL_NAME "EqualX"
#define APP_NAME "equalx"
#define APP_VERSION "0.5.1"
#define APP_SITE "http://equalx.sourceforge.net/"
#define AUTHOR_NAME "Mihai Niculescu"
#define AUTHOR_EMAIL "q.quark@gmail.com"

/*
*   DEFAULT SETTINGS for QSettings
*/
// GENERAL defaults
#define SETTINGS_DIR "equalx"
#define SETTINGS_FILE "settings"
#define DEFAULT_REMEMBER_LAYOUT true
#define DEFAULT_WINDOW_WIDTH 400
#define DEFAULT_WINDOW_HEIGHT 500
#define DEFAULT_WINDOW_X 200
#define DEFAULT_WINDOW_Y 200
#define DEFAULT_SHOW_TOOLBAR true
#define DEFAULT_SHOW_MAIN_TOOLBAR false
#define DEFAULT_SHOW_PANEL_SYMBOLS true
#define DEFAULT_SHOW_PANEL_TEMPLATES true
#define DEFAULT_SHOW_PANEL_PROPERTIES true
#define DEFAULT_MAX_RECENT_FILES 5
#define DEFAULT_SHOW_LOG false
#define DEFAULT_SHOW_PREAMBLE false
#define DEFAULT_EXPORT_TYPE 4
// EDITOR defaults
#define DEFAULT_FONT "Courier"
#define DEFAULT_FONT_SIZE 10
#define DEFAULT_HIGHLIGHTING true
#define DEFAULT_WRAPPING true
//#define DEFAULT_BRACKETS_AUTO true
//#define DEFAULT_BRACKETS_HL true
#define DEFAULT_COMPLETION false
// PREVIEW defaults
#define DEFAULT_UPDATE_AUTO true
#define DEFAULT_UPDATE_TIME 200
#define DEFAULT_ZOOM_VALUE 100
#define DEFAULT_ZOOM_PAGE 100
#define DEFAULT_ZOOM_MIN 100
#define DEFAULT_ZOOM_MAX 3200


// LATEX
#ifdef UNIX_PLATFORM
#define DEFAULT_LATEXDVI "/usr/bin/latex"
#define DEFAULT_LATEXDVI_ARGS " -interaction=nonstopmode %1"

#define DEFAULT_DVIPNG "/usr/bin/dvipng"
#define DEFAULT_DVIPNG_ARGS " -T tight -D %3 -bg %4 -o %1 %2"

#define DEFAULT_DVIGIF "/usr/bin/dvigif"
#define DEFAULT_DVIGIF_ARGS "-T tight -D %3 -bg %4 -o %1 %2"

#define DEFAULT_DVIPDF "/usr/bin/dvipdfm"
#define DEFAULT_DVIPDF_ARGS "-o %1 %2"

#define DEFAULT_DVIPS "/usr/bin/dvips"
#define DEFAULT_DVIPS_ARGS "-o %1 %2"
#endif

#ifdef WIN_PLATFORM
#define DEFAULT_LATEXDVI "C:/Program Files/MiKTeX 2.9/miktex/bin/latex.exe"
#define DEFAULT_LATEXDVI_ARGS "-interaction=nonstopmode %1"

#define DEFAULT_DVIPNG "C:/Program Files/MiKTeX 2.9/miktex/bin/dvipng.exe"
#define DEFAULT_DVIPNG_ARGS "-T tight -D %3 -bg %4 -o %1 %2"

#define DEFAULT_DVIGIF "C:/Program Files/MiKTeX 2.9/miktex/bin/dvipng.exe"
#define DEFAULT_DVIGIF_ARGS "--gif -T tight -D %3 -bg %4 -o %1 %2"

#define DEFAULT_DVIPDF "C:/Program Files/MiKTeX 2.9/miktex/bin/dvipdfm.exe"
#define DEFAULT_DVIPDF_ARGS "-o %1 %2"

#define DEFAULT_DVIPS "C:/Program Files/MiKTeX 2.9/miktex/bin/dvips.exe"
#define DEFAULT_DVIPS_ARGS "-o %1 %2"

#endif

#define MAX_RECENT_FILES 10
#define TEMP_FILE_NAME "equation"

/*
 * defines for parsing the .tex file
 */
#define BLOCK_START_L "[%- IF "
#define BLOCK_START_R " -%]"
#define BLOCK_END_L "[%- END "
#define BLOCK_END_R " -%]"

#define ELEMENT_L "[% "
#define ELEMENT_R " %]"

// defines for PNG Header Info
#define INFO_HEADER_LATEX "Latex"
#define INFO_HEADER_GEN "Generator"
#define INFO_HEADER_GEN_VER "Generator_Version"
#define INFO_HEADER_FG "Foreground"
#define INFO_HEADER_BG "Background"
#define INFO_HEADER_RES "Resolution"
#define INFO_HEADER_PREAMBLE "Preamble"



class QString;

namespace Util{


   QString getTempFile();

   // compute font resolution from Font Size in Points
    int getFontResolution(int fontSizePt);
}



#endif // DEFINES_H
